Changelog
=========

v0.0.3 (20210304)
-----------------

    - Remove redundant dependency declaration in readme
    - Update dependency version

v0.0.2 (20210303)
-----------------

    - Package some non python files

v0.0.1 (20210303)
-----------------

    - Initial version